==> kvpnc_0.8.orig.tar.gz: kvpnc-0.8/src/importprofiledialog.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef IMPORTPROFILEDIALOG_H
#define IMPORTPROFILEDIALOG_H

#include <kdialogbase.h>
#include "importprofiledialogbase.h"
#include "vpnaccountdata.h"

/**
@author Christoph Thielecke
*/
class ImportProfileDialog : public KDialogBase
{
Q_OBJECT
public:
	ImportProfileDialog( QWidget *parent, const QString& caption);
	~ImportProfileDialog();
	
	void canAccept();
	QString downloadDecPasswd(QString enc);
	bool decodeEncPasswd;
	QString filename;
	bool importOk;
	VpnAccountData *acc;
	ImportProfileDialogBase *main;
	
public slots:
	void accept();	
	
};

#endif

==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/importprofiledialog.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef IMPORTPROFILEDIALOG_H
#define IMPORTPROFILEDIALOG_H

#include <kdialogbase.h>
#include "importprofiledialogbase.h"
#include "vpnaccountdata.h"
#include "kvpncconfig.h"

/**
@author Christoph Thielecke
*/
class ImportProfileDialog : public KDialogBase
{
Q_OBJECT
public:
	ImportProfileDialog( KVpncConfig *config, QWidget *parent, const QString& caption);
	~ImportProfileDialog();
	
	void canAccept();
	bool decodeEncPasswd;
	QString filename;
	bool importOk;
	VpnAccountData *acc;
	ImportProfileDialogBase *main;
	
public slots:
	void accept();	

private:
	KVpncConfig* config;

};

#endif
